ExternalWalletIdentity class

Represents an external wallet identity.

Inheritance

Constructors

ExternalWalletIdentity(String externalWalletAddress)
const

Properties

externalWalletAddress String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Gets the primary value of the identity (e.g., email address, phone number).
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts the AuthIdentity to a map.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited