FlutterWebAuthSession class

Implementation of WebAuthenticationSession using flutter_web_auth_2.

This presents a secure, system-native WebView for authentication that integrates with the platform's security features.

Implemented types

Constructors

FlutterWebAuthSession({required String callbackUrlScheme})
Creates a new FlutterWebAuthSession with the specified callback URL scheme.

Properties

callbackUrlScheme String
The URL scheme that will be used for callbacks.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate({required Uri url, String? callbackUrlScheme}) Future<Uri?>
Presents a web authentication session with the specified URL.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited