JwtResponse class

Response from issuing a JWT for server-side authentication.

Constructors

JwtResponse({required String token, required String keyId})
const
JwtResponse.fromJson(String source)
factory
JwtResponse.fromMap(Map<String, dynamic> params)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
keyId String
The key ID used to sign the token (for JWKS lookup).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
The signed JWT token.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited