ParaAuthExtensions extension

Authentication extensions for the Para class.

on

Methods

handleLogin({required AuthState authState, required ParaWebAuthenticationSession webAuthenticationSession}) Future<void>

Available on Para, provided by the ParaAuthExtensions extension

Handles login automatically by selecting the best available signupMethod.
handleLoginWithMethod({required AuthState authState, required LoginMethod method, required ParaWebAuthenticationSession webAuthenticationSession}) Future<void>

Available on Para, provided by the ParaAuthExtensions extension

Handles login with a specific method for an existing user.
handleSignup({required AuthState authState, required SignupMethod signupMethod, required ParaWebAuthenticationSession webAuthenticationSession}) Future<void>

Available on Para, provided by the ParaAuthExtensions extension

Handles signup with a specific method for a new user.
initiateAuthFlow({required Auth auth}) Future<AuthState>

Available on Para, provided by the ParaAuthExtensions extension

Initiates the authentication flow using the provided authentication information.
isLoginMethodAvailable(LoginMethod method, AuthState authState) bool

Available on Para, provided by the ParaAuthExtensions extension

Checks if a specific login method is available for the given authentication state.
isSignupMethodAvailable(SignupMethod signupMethod, AuthState authState) bool

Available on Para, provided by the ParaAuthExtensions extension

Checks if a specific signup method is available for the given authentication state.
presentPasswordUrl(String url, ParaWebAuthenticationSession webAuthenticationSession) Future<Uri?>

Available on Para, provided by the ParaAuthExtensions extension

Presents a password authentication URL in a secure web view.