ParaPhantomConnector class

Constructors

ParaPhantomConnector({required Para para, required String appUrl, required String appScheme})

Properties

address String?
getter/setter pair
appScheme String
final
appUrl String
final
hashCode int
The hash code for this object.
no setterinherited
para Para
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() Future<String>
disconnect() Future<void>
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signAndSendTransaction(dynamic transaction) Future<String>
@deprecated signAndSendTransaction is no longer supported by Phantom Use signTransactionBytes and send the transaction separately
signMessage(String message) Future<String>
signTransaction(dynamic transaction) Future
@deprecated Use signTransactionBytes instead This method is kept for backward compatibility
signTransactionBytes(Uint8List transactionBytes) Future<String>
Sign a transaction using serialized transaction bytes This method allows using transactions built with the main solana package
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited