ParaPhantomTransactionHelper class

Helper class for working with Phantom transactions Provides utilities for encoding/decoding transactions

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

base58ToBytes(String base58String) Uint8List
Decode a base58 transaction to bytes
bytesToBase58(Uint8List bytes) String
Encode bytes to base58
signedTransactionToBase64(String base58SignedTx) String
Convert a signed transaction from Phantom (base58) to base64 for RPC
transactionBytesToBase58(Uint8List transactionBytes) String
Convert transaction bytes to base58 for Phantom