ParaWebAuthenticationSession class abstract

Interface for presenting a web authentication session.

This abstracts the authentication flow for web-based login methods, such as password authentication, allowing for consistent behavior and easier testing.

Implementers

Properties

callbackUrlScheme String
The URL scheme that will be used for callbacks.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate({required Uri url, String? callbackUrlScheme}) Future<Uri?>
Presents a web authentication session with the specified URL.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited