PregenIdentifierType enum

Inheritance
Available extensions

Values

email → const PregenIdentifierType
const PregenIdentifierType('EMAIL')
phone → const PregenIdentifierType
const PregenIdentifierType('PHONE')
customId → const PregenIdentifierType
const PregenIdentifierType('CUSTOM_ID')
discord → const PregenIdentifierType
const PregenIdentifierType('DISCORD')
twitter → const PregenIdentifierType
const PregenIdentifierType('TWITTER')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PregenIdentifierType>
A constant List of the values in this enum, in order of their declaration.