FarcasterStatus class
Represents the status of a Farcaster authentication operation.
@deprecated This class is deprecated in V2 of the Para API. Use AuthState from 'auth_state.dart' instead for V2 Farcaster authentication.
- Annotations
-
- @Deprecated('Use AuthState for V2 Farcaster authentication')
Constructors
- FarcasterStatus({required bool userExists, required String username})
-
const
- FarcasterStatus.fromJson(String source)
-
factory
-
FarcasterStatus.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userExists → bool
-
Whether the user already exists in the Para system.
final
- username → String
-
The Farcaster username of the authenticated user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited